==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/GENERATEPRODUCTIONREQUESTWOID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dbsessionid",
    "workorderid"
})
@XmlRootElement(name = "GENERATEPRODUCTIONREQUESTWOID")
public class GENERATEPRODUCTIONREQUESTWOID {

    @XmlElement(name = "DBSESSIONID", required = true)
    protected QUANTITY dbsessionid;
    @XmlElement(name = "WORKORDERID", required = true)
    protected WOID_Type workorderid;

    /**
     * Obtient la valeur de la propriété dbsessionid.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Définit la valeur de la propriété dbsessionid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

    /**
     * Obtient la valeur de la propriété workorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Définit la valeur de la propriété workorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/GENERATEPRODUCTIONREQUESTWOID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dbsessionid",
    "workorderid"
})
@XmlRootElement(name = "GENERATEPRODUCTIONREQUESTWOID")
public class GENERATEPRODUCTIONREQUESTWOID {

    @XmlElement(name = "DBSESSIONID", required = true)
    protected QUANTITY dbsessionid;
    @XmlElement(name = "WORKORDERID", required = true)
    protected WOID_Type workorderid;

    /**
     * Gets the value of the dbsessionid property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Sets the value of the dbsessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

}
